Installation
============
SKLL can easily be installed via pip::

	pip install skll

It can also be downloaded directly from
`Github <http://github.com/EducationalTestingService/skll>`_.


License
=======
SKLL is distributed under the 3-clause BSD License.
